=========
Tutorials
=========

Introduction
============
.. toctree::
    :maxdepth: 2

    quickstart

Basics
======
.. toctree::
    :maxdepth: 2

    standalone_minion
    firewall
    cron
    modules
    pillar

States
======
.. toctree::
    :maxdepth: 2

    starting_states
    states_pt1
    states_pt2
    states_pt3
    states_pt4
    states_pt5
    syslog_ng-state-usage

Advanced Topics
===============
.. toctree::
    :maxdepth: 2

    walkthrough
    rooted
    minionfs
    esky
    multimaster
    multimaster_pki
    preseed_key
    salt_bootstrap
    gitfs
    walkthrough_macosx
    writing_tests
    http
    lxc
    stormpath

Salt Virt
=========
.. toctree::
    :maxdepth: 2

    cloud_controller

LXC
===
.. toctree::
    :maxdepth: 2

    lxc

ESXi Proxy Minion
=================
.. toctree::
    :maxdepth: 2

    esxi_proxy_minion

Using Salt at scale
===================
.. toctree::
    :maxdepth: 2

    intro_scale
